rm(list = ls())

###Load data
Metabolic_data<-read.csv("Data.csv")
head(Metabolic_data)

##Subset data
Experimental_context<-subset(Metabolic_data, Metabolic_data$Exp_context=="SW Iceland_CH")
#Rename data
met.data<-Experimental_context

met.data$temp_K<-met.data$MeanT_Chamber+273.15
boltz <- 0.00008617343   ## Boltzmann constant
T0<-mean(met.data$temp_K)     ## Mean temperature
met.data$temp.kT<-(met.data$temp_K-T0)/(boltz*met.data$temp_K*T0)

#MTE models for each subset of the data per SP
met.dataSP<-subset(met.data, SP=="Salmo trutta")

## This is the original MTE model and how to mass-correct and temperature-correct metabolism using it
mSP <- lm(log(MR) ~ log(Weight_g) + temp.kT, data=met.dataSP)
summary(mSP)

####Save results
sink(file = paste("MTE",met.dataSP$SP[1],"_",met.dataSP$Exp_context[1],".txt",sep = ""))
print(summary(mSP))
print(confint(mSP,level=0.95))  #Gives parameter in the 95 confidence interval
sink(file = NULL)

met.dataSP$mc_resp <- met.dataSP$MR / met.dataSP$Weight_g^(coef(mSP)[2])
met.dataSP$tc_resp <- met.dataSP$MR / exp(met.dataSP$temp.kT*(coef(mSP)[3]))

## This is how to plot the mass-corrected metabolic rate v temperature
mc_modST <- lm(log(mc_resp) ~ temp.kT, data=met.dataSP)
#Save individual model data
sink(file = paste("mc_mod",met.dataSP$SP[1],"_",met.dataSP$Exp_context[1],".txt",sep = ""))
print(summary(mc_modST))
sink(file = NULL)

tiff(paste("Figure2_b_",met.dataSP$SP[1],"_",met.dataSP$Exp_context[1],".tiff",sep = ""), units="in", width=5, height=5, res=800)
par(mgp=c(2.2,1,0),mar=c(4.5,3.5,2,0.5),cex.axis=1,cex.lab=1,cex.main=1, cex.sub=1)
x_lab=paste()
y_lab=paste()
plot(log(mc_resp) ~ MeanT_Chamber, data=met.dataSP,ylab=(y_lab),xlab=(x_lab),
     col=c("black")[as.factor(SP)],pch = 1,  xaxt="n",yaxt="n",cex = 1.15,
     main=substitute(paste(italic(''))),
     xlim=c(4,20), 
     ylim=c(-2,3))
axis(1, labels=c(4,6,8,10,12,14,16,18,20), at=c(4,6,8,10,12,14,16,18,20),cex.axis=0.9) 
axis(2, labels=seq(from = -5, to = 5, by =0.5), at=seq(from = -5, to = 5, by =0.5),cex.axis=0.9)

xval <- range(met.dataSP$MeanT_Chamber)
xval.kT <- range(met.dataSP$temp.kT)
yval <- coef(mc_modST)[1] + coef(mc_modST)[2]*xval.kT
lines(xval, yval, col="black",lwd = 4)
mtext(substitute(paste(bold("b"))), side=3, line=0.4, adj=0, font=1,cex=1.35)
mtext(quote(Chronic~exposure~(SW~Iceland_[CH])), side=3, line=0.2,cex=1)  ####Change in here the name of the experimental context
mtext(substitute(paste("Temperature (C)")), side=1, line=2.65,cex=1)

####Plot interval confidence
model_plot1<-lm(log(mc_resp) ~ MeanT_Chamber,data=met.dataSP)
newx <- seq(min(met.dataSP$MeanT_Chamber),max(met.dataSP$MeanT_Chamber),by = 0.05)
conf_interval <- predict(model_plot1, newdata=data.frame(MeanT_Chamber=newx), interval="confidence",level = 0.95)
lines(newx, conf_interval[,2], col="black", lty=2)
lines(newx, conf_interval[,3], col="black", lty=2)
graphics.off()

## This is how to plot the temperature-corrected metabolic rate v body mass
tc_modST <- lm(log(tc_resp) ~ log(Weight_g), data=met.dataSP)
#Save individual model data
sink(file = paste("tc_mod",met.dataSP$SP[1],"_",met.dataSP$Exp_context[1],".txt",sep = ""))
print(summary(tc_modST))
sink(file = NULL)

y_lab=paste()
x_lab=expression()
tiff(paste("Figure2_d_",met.dataSP$SP[1],"_",met.dataSP$Exp_context[1],".tiff",sep = ""), units="in", width=5, height=5, res=800)
par(mgp=c(2.2,1,0),mar=c(4.5,3.5,2,0.5),cex.axis=1,cex.lab=1,cex.main=1, cex.sub=1)
plot(log(tc_resp) ~ log(Weight_g), data=met.dataSP,ylab=(y_lab),xlab=(x_lab),
     col=c("black")[as.factor(SP)],pch = 1, xaxt="n",yaxt="n",cex = 1.15,
     main=substitute(paste(italic(''))),
     xlim=c(0,6),
     ylim=c(-1,4))
axis(1, labels=seq(from = -1, to = 6, by =0.5), at=seq(from = -1, to = 6, by =0.5),cex.axis=0.9)
axis(2, labels=seq(from = -5, to = 5, by =0.5), at=seq(from = -5, to = 5, by =0.5),cex.axis=0.9)

xval <- log(range(met.dataSP$Weight_g))
yval <- coef(tc_modST)[1] + coef(tc_modST)[2]*xval
lines(xval, yval, col="black",lwd = 4)
mtext(substitute(paste(bold("d"))), side=3, line=0.4, adj=0, font=1,cex=1.35)
mtext(expression(Ln~ body~ mass~ (g)), side=1, line=2.65,cex=1)

####Plot interval confidence
model_plot1<-lm(log(tc_resp) ~ log(Weight_g),data=met.dataSP)
newx <- seq(min(met.dataSP$Weight_g),max(met.dataSP$Weight_g),by = 0.05)
conf_interval <- predict(model_plot1, newdata=data.frame(Weight_g=newx),interval="confidence",level = 0.95)
lines(log(newx), conf_interval[,2], col="black", lty=2)
lines(log(newx), conf_interval[,3], col="black", lty=2)

graphics.off()
